<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\Clinic;
use App\User;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Facades\Mail;

class UserController extends Controller
{
    public $table = 'users';
    public $model = 'User';
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $users = User::orderBy('created_at', 'desc')->paginate(30);
        $table = 'users';
        return view('admin.users.index', compact('users', 'table'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        $table = $this->table;
        $model = new User();
        $clinic = new Clinic();
        return view('admin.users.create', compact('clinic', 'model', 'table'));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $data = $request->validate([
            'name' => 'required|string|max:255',
            'email' => 'required|string|email|max:255|unique:users',
            'password' => 'required|string|min:8|confirmed'
        ]);

        $user = new User();
        $user->name = $request->name;
        $user->email = $request->email;
        // $password = str_random(8);
        $password = $request->password;
        $user->password = Hash::make($password);
        $user->user_type = 'clinic';
        $user->save();

        $clinic = new Clinic();
        $clinic->code = $request->clinic_code;
        $clinic->name = $request->name;
        $clinic->email = $request->email;
        $clinic->phone = $request->phone;
        $clinic->address = $request->address;
        $clinic->address_2 = $request->address_2;
        $clinic->city = $request->city;
        $clinic->province = $request->province;
        $clinic->postal_code = $request->postal_code;
        $clinic->user()->associate($user);
        $clinic->save();
        // $user->notify(new \App\Notifications\ClinicCreated($user, $clinic));
        Mail::to('service3d@labbellomo.com')->bcc('digitalpixel93@gmail.com')->send(new \App\Mail\ClinicCreated($user, $clinic));
        
        $request->session()->flash('alert-success', 'Clinic added successfully');
        return redirect()->back();
    }

    /**
     * Display the specified resource.
     *
     * @param  \App\User  $user
     * @return \Illuminate\Http\Response
     */
    public function show(User $user)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  \App\User  $user
     * @return \Illuminate\Http\Response
     */
    public function edit(User $user)
    {
        $table = $this->table;
        $model = $user;
        $clinic = Clinic::where('user_id', $user->id)->first();
        return view('admin.users.edit', compact('clinic', 'model', 'table'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \App\User  $user
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, User $user)
    {
        $clinic = Clinic::where('user_id', $user->id)->first();
        $clinic->phone = $request->clinic_phone;
        $clinic->address = $request->clinic_address;
        $clinic->address_2 = $request->clinic_address_2;
        $clinic->city = $request->clinic_city;
        $clinic->province = $request->clinic_province;
        $clinic->postal_code = $request->clinic_postal_code;
        $request->session()->flash('alert-success', 'Clinic updated successfully');
        return redirect()->route('admin.users.index');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  \App\User  $user
     * @return \Illuminate\Http\Response
     */
    public function destroy(User $user)
    {
        //
    }
}
