<?php

namespace App\Http\Controllers;

use App\Models\Clinic;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Hash;
use App\User;
use App\Models\Patient;
use Illuminate\Support\Facades\Gate;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Mail;

class ClinicController extends Controller
{
        /**
         * Display a listing of the resource.
         *
         * @return \Illuminate\Http\Response
         */
        public function index(Request $request)
        {
                if (!Gate::allows('isAdmin')) {
                        abort(404);
                }
                if ($request->ajax()) {
                        // dd($request->search);
                        $clinics = Clinic::from('clinics');
                        if (!empty($request->search))
                                $clinics = $clinics->where('name', 'like', '%' . $request->search . '%');
                        if (!empty($request->sort))
                                $clinics = $clinics->orderBy($request->sort);
                        $clinics = $clinics->get();
                        return response()->json(['clinics' => $clinics]);
                }
                $clinics = Clinic::orderBy('created_at', 'desc')->get();
                return view('clinics/index', [
                        'clinics' => $clinics,
                        'title' => 'Admin Dashboard'
                ]);
        }

        /**
         * Show the form for creating a new resource.
         *
         * @return \Illuminate\Http\Response
         */
        public function create()
        {
                //
        }

        /**
         * Store a newly created resource in storage.
         *
         * @param  \Illuminate\Http\Request  $request
         * @return \Illuminate\Http\Response
         */
        public function store(Request $request)
        {
                if ($request->ajax()) {
                        if (User::where('email', $request->clinic_email)->count())
                                return response()->json(['status' => 0, 'msg' => 'This email is already registered']);
                        $user = new User();
                        $user->name = $request->clinic_name;
                        $user->email = $request->clinic_email;
                        // $password = str_random(8);
                        $password = '12345678';
                        $user->password = Hash::make($password);
                        $user->user_type = 'clinic';
                        $user->save();

                        $clinic = new Clinic();
                        $clinic->code = $request->clinic_code;
                        $clinic->name = $request->clinic_name;
                        $clinic->email = $request->clinic_email;
                        $clinic->phone = $request->clinic_phone;
                        $clinic->address = $request->clinic_address;
                        $clinic->address_2 = $request->clinic_address_2;
                        $clinic->city = $request->clinic_city;
                        $clinic->province = $request->clinic_province;
                        $clinic->postal_code = $request->clinic_postal_code;
                        $clinic->user()->associate($user);
                        $clinic->save();
                        // $user->notify(new \App\Notifications\RequestQuote($user, $request->service, $request->message));
                        // $user->notify(new \App\Notifications\ClinicCreated($user, $clinic));
                        return response()->json(['clinic' => $clinic, 'msg' => 'Dental Clinic Folder Created Successfully']);
                }
                $request->validate([
                        'name' => 'required|string|max:255',
                        'email' => 'required|string|email|max:255|unique:users',
                        'password' => 'required|string|min:8|confirmed',
                        'g-recaptcha-response' => 'required|captcha',
                ]);



                $user = new User();
                $user->name = $request->name;
                $user->email = $request->email;
                // $password = str_random(8);
                $password = $request->password;
                $user->password = Hash::make($password);
                $user->user_type = 'clinic';
                $user->save();

                $clinic = new Clinic();
                $clinic->code = $request->clinic_code;
                $clinic->name = $request->name;
                $clinic->email = $request->email;
                $clinic->phone = $request->clinic_phone;
                $clinic->address = $request->clinic_address;
                $clinic->address_2 = $request->clinic_address_2;
                $clinic->city = $request->clinic_city;
                $clinic->province = $request->clinic_province;
                $clinic->postal_code = $request->clinic_postal_code;
                $clinic->user()->associate($user);
                $clinic->save();
                $user->notify(new \App\Notifications\ClinicCreated($user, $clinic));
                try {
                        Mail::to('service3d@labbellomo.com')->bcc('laboratoirebellomo@gmail.com')->send(new \App\Mail\ClinicCreated($user, $clinic));
                } catch (\Throwable $th) {
                        //throw $th;
                }
                Auth::login($user);
                $request->session()->flash('alert-success', 'Thanks for regestring with us');
                return redirect()->back();
        }

        /**
         * Display the specified resource.
         *
         * @param  \App\Models\Clinic  $clinic
         * @return \Illuminate\Http\Response
         */
        public function show(Clinic $clinic, Request $request)
        {
                if ($request->ajax()) {
                        return response()->json(['clinic' => $clinic]);
                }

                // $patients = Patient::where('clinic_id', $clinic->id);

                //     $patients->where()

                // $patients = $patients->get();
                if (!$this->checkAuth($clinic))
                        return redirect('http://labbellomo.com/404');

                return view('clinics/show', ['clinic' => $clinic, 'patients' => $clinic->patients]);
        }

        /**
         * Show the form for editing the specified resource.
         *
         * @param  \App\Models\Clinic  $clinic
         * @return \Illuminate\Http\Response
         */
        public function edit(Clinic $clinic)
        {
                //
        }

        /**
         * Update the specified resource in storage.
         *
         * @param  \Illuminate\Http\Request  $request
         * @param  \App\Models\Clinic  $clinic
         * @return \Illuminate\Http\Response
         */
        public function update(Request $request, Clinic $clinic)
        {
                if ($request->ajax()) {
                        $clinic->code = $request->clinic_code;
                        $clinic->name = $request->clinic_name;
                        $clinic->phone = $request->clinic_phone;
                        $clinic->address = $request->clinic_address;
                        $clinic->address_2 = $request->clinic_address_2;
                        $clinic->city = $request->clinic_city;
                        $clinic->province = $request->clinic_province;
                        $clinic->postal_code = $request->clinic_postal_code;
                        $clinic->save();
                        return response()->json(['clinic' => $clinic, 'msg' => 'clinic deleted successfully']);
                }
                $clinic->code = $request->clinic_code;
                $clinic->phone = $request->clinic_phone;
                $clinic->address = $request->clinic_address;
                $clinic->address_2 = $request->clinic_address_2;
                $clinic->city = $request->clinic_city;
                $clinic->province = $request->clinic_province;
                $clinic->postal_code = $request->clinic_postal_code;
                $clinic->save();
                if (!empty($request->current_password)) {
                        $request->validate([
                                'current_password' => 'required',
                                'new_password' => 'required|string|min:8|confirmed'
                        ]);
                        if (!(Hash::check($request->get('current_password'), Auth::user()->password))) {
                                // The passwords matches
                                return redirect()->back()->with("error", "Your current password does not matches with the password you provided. Please try again.");
                        }

                        if (strcmp($request->get('current_password'), $request->get('new_password')) == 0) {
                                //Current password and new password are same
                                return redirect()->back()->with("error", "New Password cannot be same as your current password. Please choose a different password.");
                        }
                        //Change Password
                        $user = Auth::user();
                        $user->password = bcrypt($request->get('new_password'));
                        $user->save();
                        return redirect()->back()->with("success", "Password changed successfully !");
                }
                return redirect()->back()->with("success", "Clinic updated successfully !");
        }

        /**
         * Remove the specified resource from storage.
         *
         * @param  \App\Models\Clinic  $clinic
         * @return \Illuminate\Http\Response
         */
        public function destroy(Clinic $clinic)
        {
                User::where('email', $clinic->email)->delete();
                $clinic->delete();
                return response()->json(['msg' => 'clinic deleted successfully']);
        }

        public function checkAuth($clinic)
        {
                if (Gate::allows('isAdmin'))
                        return true;
                if (Gate::allows('isClinic')) {
                        if ($clinic->user_id == Auth::user()->id)
                                return true;
                }
                // abort(404);
                return false;
        }
}
